# Installation

You can install kr8s from PyPI using `pip`.

```console
$ pip install kr8s
```

## Supported Kubernetes Versions

We endeavor to support all Kubernetes versions that are [actively supported by the Kubernetes community](https://kubernetes.io/releases/).
Kubernetes typically releases 3-4 times a year and provides 1 year of patch support.
